==> dasu_4.11.jar: edu/northwestern/dasu/drools/FactMeasurementRpss.java <==
/**
 * Dasu Project
 *
 * File:         FactMeasurementLpsd.java
 * RCS:          $Id$
 * Description:  FactMeasurementLpsd class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 21, 2010 at 10:08:18 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

import org.gudy.azureus2.plugins.download.DownloadException;

import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.stats.RemotePeerStatStatic;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactMeasurementLpsd class ...
 * For a member to be visible to Jess (as part of the fact)  
 * it must have it's own public setter and getter functions
 */
public class FactMeasurementRpss extends FactMeasurement<RemotePeerStatStatic> {

		private String peerIp;
		private long downloadId;
		private long currentLifetime;
		private int tcpPort;
		private int udpPort;	
		private long firstSeen;
		private String encryption;
		private int type = -1;
		private long pieceSize;
		private boolean isInteresting;
		private boolean isInterested;
		private double ping = -2;
		private long bytesSentToPeer;
		private long bytesReceivedFromPeer;
		private int sendRate;
		private int receiveRate;
		private boolean isSeed= false;

        
		public FactMeasurementRpss() {
			
		}
		
		public FactMeasurementRpss(RemotePeerStatStatic rpss) {

			try {
				this.downloadId = Main.getId(rpss.getPeer().getManager().getDownload());
			} catch (DownloadException e) {
				//e.printStackTrace();
			}
			this.peerIp = rpss.getPeer().getIp();
			this.currentLifetime = rpss.currentLifetime;
			this.tcpPort = rpss.tcpPort;
			this.udpPort = rpss.udpPort;
			this.firstSeen = rpss.firstSeen;
			this.encryption = rpss.encryption;
			this.type = rpss.type;
			this.pieceSize = rpss.pieceSize;
			this.isInteresting = rpss.getPeer().isInteresting();
			this.isInterested = rpss.getPeer().isInterested();
			if (rpss.getDynamicStats().size() > 0)
				this.ping = rpss.getDynamicStats().get(rpss.getDynamicStats().size()-1).ping;
				
			this.bytesSentToPeer = rpss.getPeer().getStats().getTotalSent();
			this.bytesReceivedFromPeer = rpss.getPeer().getStats().getTotalReceived();
			this.sendRate = rpss.getPeer().getStats().getUploadAverage();
			this.receiveRate = rpss.getPeer().getStats().getDownloadAverage();
			this.isSeed= rpss.getPeer().isSeed();

		}

		public String getPeerIp() {
			return peerIp;
		}

		public long getDownloadId() {
			return downloadId;
		}

		public long getCurrentLifetime() {
			return currentLifetime;
		}

		public int getTcpPort() {
			return tcpPort;
		}

		public int getUdpPort() {
			return udpPort;
		}

		public long getFirstSeen() {
			return firstSeen;
		}

		public String getEncryption() {
			return encryption;
		}

		public int getType() {
			return type;
		}

		public long getPieceSize() {
			return pieceSize;
		}

		public boolean isInteresting() {
			return isInteresting;
		}

		public boolean isInterested() {
			return isInterested;
		}

		public double getPing() {
			return ping;
		}

		public long getBytesSentToPeer() {
			return bytesSentToPeer;
		}

		public long getBytesReceivedFromPeer() {
			return bytesReceivedFromPeer;
		}

		public int getSendRate() {
			return sendRate;
		}

		public int getReceiveRate() {
			return receiveRate;
		}

		public boolean isSeed() {
			return isSeed;
		}

		public void setPeerIp(String peerIp) {
			this.peerIp = peerIp;
		}

		public void setDownloadId(long downloadId) {
			this.downloadId = downloadId;
		}

		public void setCurrentLifetime(long currentLifetime) {
			this.currentLifetime = currentLifetime;
		}

		public void setTcpPort(int tcpPort) {
			this.tcpPort = tcpPort;
		}

		public void setUdpPort(int udpPort) {
			this.udpPort = udpPort;
		}

		public void setFirstSeen(long firstSeen) {
			this.firstSeen = firstSeen;
		}

		public void setEncryption(String encryption) {
			this.encryption = encryption;
		}

		public void setType(int type) {
			this.type = type;
		}

		public void setPieceSize(long pieceSize) {
			this.pieceSize = pieceSize;
		}

		public void setInteresting(boolean isInteresting) {
			this.isInteresting = isInteresting;
		}

		public void setInterested(boolean isInterested) {
			this.isInterested = isInterested;
		}

		public void setPing(double ping) {
			this.ping = ping;
		}

		public void setBytesSentToPeer(long bytesSentToPeer) {
			this.bytesSentToPeer = bytesSentToPeer;
		}

		public void setBytesReceivedFromPeer(long bytesReceivedFromPeer) {
			this.bytesReceivedFromPeer = bytesReceivedFromPeer;
		}

		public void setSendRate(int sendRate) {
			this.sendRate = sendRate;
		}

		public void setReceiveRate(int receiveRate) {
			this.receiveRate = receiveRate;
		}

		public void setSeed(boolean isSeed) {
			this.isSeed = isSeed;
		}
	
        
}

==> dasu_5.31.jar: edu/northwestern/dasu/drools/FactMeasurementRpss.java <==
/**
 * Dasu Project
 *
 * File:         FactMeasurementLpsd.java
 * RCS:          $Id$
 * Description:  FactMeasurementLpsd class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Jul 21, 2010 at 10:08:18 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.drools
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.drools;

import org.gudy.azureus2.plugins.download.DownloadException;

import edu.northwestern.dasu.Main;
import edu.northwestern.dasu.stats.RemotePeerStatStatic;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The FactMeasurementLpsd class ...
 * For a member to be visible to Jess (as part of the fact)  
 * it must have it's own public setter and getter functions
 */
public class FactMeasurementRpss extends FactMeasurement<RemotePeerStatStatic> {

		public String peerIp;
		public long downloadId;
		public long currentLifetime;
		public int tcpPort;
		public int udpPort;	
		public long firstSeen;
		public String encryption;
		public int type = -1;
		public long pieceSize;
		public boolean isInteresting;
		public boolean isInterested;
		public double ping = -2;
		public long bytesSentToPeer;
		public long bytesReceivedFromPeer;
		public int sendRate;
		public int receiveRate;
		public boolean isSeed= false;
        
		public FactMeasurementRpss() {
			
		}
		
		public FactMeasurementRpss(RemotePeerStatStatic rpss) {

			try {
				this.downloadId = Main.getId(rpss.getPeer().getManager().getDownload());
			} catch (DownloadException e) {
				//e.printStackTrace();
			}
			this.peerIp = rpss.getPeer().getIp();
			this.currentLifetime = rpss.currentLifetime;
			this.tcpPort = rpss.tcpPort;
			this.udpPort = rpss.udpPort;
			this.firstSeen = rpss.firstSeen;
			this.encryption = rpss.encryption;
			this.type = rpss.type;
			this.pieceSize = rpss.pieceSize;
			this.isInteresting = rpss.getPeer().isInteresting();
			this.isInterested = rpss.getPeer().isInterested();
			if (rpss.getDynamicStats().size() > 0)
				this.ping = rpss.getDynamicStats().get(rpss.getDynamicStats().size()-1).ping;
				
			this.bytesSentToPeer = rpss.getPeer().getStats().getTotalSent();
			this.bytesReceivedFromPeer = rpss.getPeer().getStats().getTotalReceived();
			this.sendRate = rpss.getPeer().getStats().getUploadAverage();
			this.receiveRate = rpss.getPeer().getStats().getDownloadAverage();
			this.isSeed= rpss.getPeer().isSeed();

		}

		public String getPeerIp() {
			return peerIp;
		}

		public long getDownloadId() {
			return downloadId;
		}

		public long getCurrentLifetime() {
			return currentLifetime;
		}

		public int getTcpPort() {
			return tcpPort;
		}

		public int getUdpPort() {
			return udpPort;
		}

		public long getFirstSeen() {
			return firstSeen;
		}

		public String getEncryption() {
			return encryption;
		}

		public int getType() {
			return type;
		}

		public long getPieceSize() {
			return pieceSize;
		}

		public boolean isInteresting() {
			return isInteresting;
		}

		public boolean isInterested() {
			return isInterested;
		}

		public double getPing() {
			return ping;
		}

		public long getBytesSentToPeer() {
			return bytesSentToPeer;
		}

		public long getBytesReceivedFromPeer() {
			return bytesReceivedFromPeer;
		}

		public int getSendRate() {
			return sendRate;
		}

		public int getReceiveRate() {
			return receiveRate;
		}

		public boolean isSeed() {
			return isSeed;
		}

		public void setPeerIp(String peerIp) {
			this.peerIp = peerIp;
		}

		public void setDownloadId(long downloadId) {
			this.downloadId = downloadId;
		}

		public void setCurrentLifetime(long currentLifetime) {
			this.currentLifetime = currentLifetime;
		}

		public void setTcpPort(int tcpPort) {
			this.tcpPort = tcpPort;
		}

		public void setUdpPort(int udpPort) {
			this.udpPort = udpPort;
		}

		public void setFirstSeen(long firstSeen) {
			this.firstSeen = firstSeen;
		}

		public void setEncryption(String encryption) {
			this.encryption = encryption;
		}

		public void setType(int type) {
			this.type = type;
		}

		public void setPieceSize(long pieceSize) {
			this.pieceSize = pieceSize;
		}

		public void setInteresting(boolean isInteresting) {
			this.isInteresting = isInteresting;
		}

		public void setInterested(boolean isInterested) {
			this.isInterested = isInterested;
		}

		public void setPing(double ping) {
			this.ping = ping;
		}

		public void setBytesSentToPeer(long bytesSentToPeer) {
			this.bytesSentToPeer = bytesSentToPeer;
		}

		public void setBytesReceivedFromPeer(long bytesReceivedFromPeer) {
			this.bytesReceivedFromPeer = bytesReceivedFromPeer;
		}

		public void setSendRate(int sendRate) {
			this.sendRate = sendRate;
		}

		public void setReceiveRate(int receiveRate) {
			this.receiveRate = receiveRate;
		}

		public void setSeed(boolean isSeed) {
			this.isSeed = isSeed;
		}
	
        
}
